==> department-2.2.0.tgz: package/es/scenes/Auth/components/Login.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { withRouter } from 'react-router-dom';
import Helmet from 'react-helmet';
import { SubmissionError } from 'redux-form';
import { loginUser } from '../utilities';
import LoginForm from './components/LoginForm';

var Login = function (_PureComponent) {
  _inherits(Login, _PureComponent);

  function Login() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, Login);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = Login.__proto__ || Object.getPrototypeOf(Login)).call.apply(_ref, [this].concat(args))), _this), _this.handleSubmit = function (values) {
      return loginUser(values).then(function () {
        var path = _this.props.location.state && _this.props.location.state.redirectPath || '/';

        _this.props.history.push(path);
      }, function (err) {
        throw new SubmissionError({ _error: err.json && err.json.message || err.statusText });
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(Login, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        'section',
        { className: 'department-main' },
        React.createElement(
          Helmet,
          null,
          React.createElement(
            'title',
            null,
            'Log in'
          )
        ),
        React.createElement(
          'main',
          { className: 'card login' },
          React.createElement(LoginForm, { onSubmit: this.handleSubmit })
        )
      );
    }
  }]);

  return Login;
}(PureComponent);

Login.propTypes = {
  history: PropTypes.object.isRequired,
  location: PropTypes.object.isRequired
};

export default withRouter(Login);

==> department-2.4.2.tgz: package/es/scenes/Auth/components/Login.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { withApollo } from 'react-apollo';
import { SubmissionError } from 'redux-form';
import Helmet from 'react-helmet';
import cookie from 'js-cookie';
import { authenticateByCredentialsQuery } from '../api';
import LoginForm from './components/LoginForm';

var Login = function (_PureComponent) {
  _inherits(Login, _PureComponent);

  function Login() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, Login);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = Login.__proto__ || Object.getPrototypeOf(Login)).call.apply(_ref, [this].concat(args))), _this), _this.handleSubmit = function (values) {
      return _this.props.client.query({
        query: authenticateByCredentialsQuery,
        variables: { username: values.username, password: values.password }
      }).then(function (response) {
        var token = response.data.authenticateByCredentials.token;
        var path = _this.props.location.state && _this.props.location.state.from || '/';

        cookie.set('token', token);

        _this.props.history.replace(path);
      }).catch(function (e) {
        var errorMessage = e.graphQLErrors.length ? e.graphQLErrors[0].message : e.message;

        throw new SubmissionError({ _error: errorMessage });
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(Login, [{
    key: 'render',
    value: function render() {
      var initialError = this.props.location.state && this.props.location.state.error;

      return React.createElement(
        'section',
        { className: 'department-main' },
        React.createElement(
          Helmet,
          null,
          React.createElement(
            'title',
            null,
            'Log in'
          )
        ),
        React.createElement(
          'main',
          { className: 'card login' },
          React.createElement(LoginForm, { onSubmit: this.handleSubmit, initialError: initialError })
        )
      );
    }
  }]);

  return Login;
}(PureComponent);

Login.propTypes = {
  client: PropTypes.object.isRequired,
  history: PropTypes.object.isRequired,
  location: PropTypes.object.isRequired
};

export default withApollo(Login);
